==> piwigo-2.7.4.zip: piwigo/language/pt_BR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalação';
$lang['Basic configuration'] = 'Configuração Básica';
$lang['Default gallery language'] = 'Idioma padrão da galeria';
$lang['Database configuration'] = 'Configuração da base de dados';
$lang['Admin configuration'] = 'Configuração da administração';
$lang['Start Install'] = 'Iniciar a instalação';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Será mostrado aos visitantes. É necessário para a administração do website';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'A conexão com o servidor foi bem sucedida, porém não foi possível se conectar à base de dados';
$lang['Can\'t connect to server'] = 'Não foi possível se conectar ao servidor';
$lang['Host'] = 'MySQL host';
$lang['User'] = 'Usuário';
$lang['user login given by your host provider'] = 'login de usuário fornecido pelo seu provedor de hospedagem';
$lang['user password given by your host provider'] = 'senha de usuário fornecida pelo seu provedor de hospedagem';
$lang['Database name'] = 'Nome da base de dados';
$lang['also given by your host provider'] = 'também forncido pelo seu provedor de hospedagem';
$lang['Database table prefix'] = 'Prefixo da tabela da base de dado';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Os nomes das tabelas da base de dados terão este prefixo (isto possibilita que você gerencie melhor suas tabelas)';
$lang['enter a login for webmaster'] = 'entre um login para o webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'o login do webmaster não pode conter os caracteres \' ou "';
$lang['please enter your password again'] = 'por favor, entre com a sua senha novamente';
$lang['Keep it confidential, it enables you to access administration panel'] = 'mantenha-a bem guardada, é ela que lhe permite acessar o painel da administração';
$lang['Password [confirm]'] = 'Senha [confirmar]';
$lang['verification'] = 'verificação';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Precisa de ajuda ? Faça a sua pergunta no <a href="%s">Piwigo message board</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Os visitantes poderão entrar em contato com o administrador do site através desse email';
$lang['PHP 5 is required'] = 'É necessário PHP 5';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que a sua hospedagem está atualmente usando PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pode tentar mudar sua configuração para PHP 5 através da criação ou modificação de um arquivo .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Note que você pode alterar sua configuração por conta própria e reiniciar o Piwigo depois disso.';
$lang['Try to configure PHP 5'] = 'Tentar configurar PHP 5';
$lang['Sorry!'] = 'Lamento!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo não teve condições de configurar o PHP 5.';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Você deve entrar em contato com o suporte do seu provedor e ver como você poderia mudar para PHP 5 por conta própria.";
$lang['Hope to see you back soon.'] = 'Espero te ver de volta em breve.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Uma solução alternativa é copiar o texto na caixa acima e cole-o no arquivo "local/config/database.inc.php" (Atenção: database.inc.php deve conter apenas o que está na área de texto, sem retorno de linha ou caractere de espaço)';
$lang['Congratulations, Piwigo installation is completed'] = 'Parabéns, a instalção do Piwigo foi completada.  ';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Criação do arquivo de configuração local/config/database.inc.php falhou.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Não hesite em consultar os nossos fóruns para qualquer ajuda: %s';
$lang['Download the config file'] = 'Baixar o arquivo de configuração.';
$lang['Just another Piwigo gallery'] = 'Apenas outra galeria Piwigo.';
$lang['Welcome to my photo gallery'] = 'Bem-Vindo a minha galeria de fotos.';
$lang['Welcome to your new installation of Piwigo!'] = 'Bem-Vindo a sua nova instalação do Piwigo.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Você pode baixar o arquivo de configuração e colocá-lo na pasta local/config de sua instalação.';
$lang['localhost or other, supplied by your host provider'] = 'localhost ou outro, fornecido pelo seu provedor de hospedagem';
?>

==> piwigo-v2.10.2.zip: piwigo/language/pt_BR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalação';
$lang['Basic configuration'] = 'Configuração Básica';
$lang['Default gallery language'] = 'Idioma padrão da galeria';
$lang['Database configuration'] = 'Configuração da base de dados';
$lang['Admin configuration'] = 'Configuração da administração';
$lang['Start Install'] = 'Iniciar a instalação';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Será mostrado aos visitantes. É necessário para a administração do website';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'A conexão com o servidor foi bem sucedida, porém não foi possível se conectar à base de dados';
$lang['Can\'t connect to server'] = 'Não foi possível se conectar ao servidor';
$lang['Host'] = 'MySQL host';
$lang['User'] = 'Usuário';
$lang['user login given by your host provider'] = 'login de usuário fornecido pelo seu provedor de hospedagem';
$lang['user password given by your host provider'] = 'senha de usuário fornecida pelo seu provedor de hospedagem';
$lang['Database name'] = 'Nome da base de dados';
$lang['also given by your host provider'] = 'também forncido pelo seu provedor de hospedagem';
$lang['Database table prefix'] = 'Prefixo da tabela da base de dado';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Os nomes das tabelas da base de dados terão este prefixo (isto possibilita que você gerencie melhor suas tabelas)';
$lang['enter a login for webmaster'] = 'entre um login para o webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'o login do webmaster não pode conter os caracteres \' ou "';
$lang['please enter your password again'] = 'por favor, entre com a sua senha novamente';
$lang['Keep it confidential, it enables you to access administration panel'] = 'mantenha-a bem guardada, é ela que lhe permite acessar o painel da administração';
$lang['Password [confirm]'] = 'Senha [confirmar]';
$lang['verification'] = 'verificação';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Precisa de ajuda ? Faça a sua pergunta no <a href="%s">Piwigo message board</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Os visitantes poderão entrar em contato com o administrador do site através desse email';
$lang['PHP 5 is required'] = 'É necessário PHP 5.2';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que a sua hospedagem está atualmente usando PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pode tentar mudar sua configuração para PHP 5.2 através da criação ou modificação de um arquivo .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Note que você pode alterar sua configuração por conta própria e reiniciar o Piwigo depois disso.';
$lang['Try to configure PHP 5'] = 'Tentar configurar PHP 5.2';
$lang['Sorry!'] = 'Lamento!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo não teve condições de configurar o PHP 5.2';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Você deve entrar em contato com o suporte do seu provedor e ver como você poderia mudar para PHP 5 por conta própria.";
$lang['Hope to see you back soon.'] = 'Espero te ver de volta em breve.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Uma solução alternativa é copiar o texto na caixa acima e cole-o no arquivo "local/config/database.inc.php" (Atenção: database.inc.php deve conter apenas o que está na área de texto, sem retorno de linha ou caractere de espaço)';
$lang['Congratulations, Piwigo installation is completed'] = 'Parabéns, a instalção do Piwigo foi completada.  ';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Criação do arquivo de configuração local/config/database.inc.php falhou.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Não hesite em consultar os nossos fóruns para qualquer ajuda: %s';
$lang['Download the config file'] = 'Baixar o arquivo de configuração.';
$lang['Just another Piwigo gallery'] = 'Apenas outra galeria Piwigo.';
$lang['Welcome to my photo gallery'] = 'Bem-Vindo a minha galeria de fotos.';
$lang['Welcome to your new installation of Piwigo!'] = 'Bem-Vindo a sua nova instalação do Piwigo.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Você pode baixar o arquivo de configuração e colocá-lo na pasta local/config de sua instalação.';
$lang['localhost or other, supplied by your host provider'] = 'localhost ou outro, fornecido pelo seu provedor de hospedagem';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Você deve entrar em contato com o suporte do seu provedor e ver como você poderia mudar para PHP 5.2 por conta própria.';
